@@ -1,24 +1,28 @@
 package Boxer;
 
+=encoding UTF-8
+
 =head1 NAME
 
 Boxer - system deployment ninja tricks
 
 =cut
 
-use strict;
-use warnings;
-
-use 5.01;
-
+use v5.14;
+use utf8;
+use strictures 2;
+use version;
 use Role::Commons -all;
 
-our $AUTHORITY = 'cpan:JONASS';
-our $VERSION = 'v1.1.2';
+use namespace::clean;
 
-1;
+=head1 VERSION
 
-__END__
+Version v1.1.5
+
+=cut
+
+our $VERSION = version->declare("v1.1.5");
 
 =head1 DESCRIPTION
 
@@ -35,11 +39,15 @@ L<boxer>.
 
 =head1 AUTHOR
 
-Jonas Smedegaard E<lt>dr@jones.dkE<gt>.
+Jonas Smedegaard C<< <dr@jones.dk> >>.
+
+=cut
+
+our $AUTHORITY = 'cpan:JONASS';
 
 =head1 COPYRIGHT AND LICENCE
 
-This software is copyright (c) 2013-2015 by Jonas Smedegaard.
+Copyright © 2013-2016 Jonas Smedegaard
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
@@ -49,3 +57,7 @@ the same terms as the Perl 5 programming language system itself.
 THIS PACKAGE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED
 WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF
 MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+
+=cut
+
+1;
