@@ -1,21 +1,32 @@
 package Boxer::CLI::Command::Compose;
 
-use 5.010;
-use strictures 1;
+=encoding UTF-8
+
+=cut
+
+use v5.14;
 use utf8;
-
-use Boxer::CLI -command;
-use namespace::clean;
-
-use Module::Runtime qw/use_module/;
+use strictures 2;
+use version;
 use Role::Commons -all;
 
-our $AUTHORITY = 'cpan:JONASS';
-our $VERSION = 'v1.1.4';
+use Path::Tiny;
+use Module::Runtime qw/use_module/;
+use Boxer::CLI -command;
+
+use namespace::clean;
+
+=head1 VERSION
+
+Version v1.1.5
+
+=cut
+
+our $VERSION = version->declare("v1.1.5");
 
 use constant {
 	abstract   => q[compose system recipe from reclass node],
-	usage_desc => q[%c install %o NODE [NODE...]],
+	usage_desc => q[%c compose %o NODE [NODE...]],
 };
 
 sub description
@@ -56,7 +67,7 @@ sub execute
 	my $self = shift;
 	my ( $opt, $args ) = @_;
 
-	my $data = use_module('Boxer::Task::Classify')->new(
+	my $world = use_module('Boxer::Task::Classify')->new(
 		suite    => $opt->{suite},
 		nodedir  => $opt->{nodedir},
 		classdir => $opt->{classdir},
@@ -64,13 +75,35 @@ sub execute
 	)->run;
 	for my $node (@$args) {
 		use_module('Boxer::Task::Serialize')->new(
+			world   => $world,
 			skeldir => $opt->{skeldir},
-			suite   => $opt->{suite},
 			nonfree => $opt->{nonfree},
-			data    => $data,
 			node    => $node,
 		)->run;
 	}
 }
 
+=head1 AUTHOR
+
+Jonas Smedegaard C<< <dr@jones.dk> >>.
+
+=cut
+
+our $AUTHORITY = 'cpan:JONASS';
+
+=head1 COPYRIGHT AND LICENCE
+
+Copyright © 2013-2016 Jonas Smedegaard
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=head1 DISCLAIMER OF WARRANTIES
+
+THIS PACKAGE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED
+WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF
+MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+
+=cut
+
 1;
